@@ -1,8 +1,8 @@
 /*
  *   This file is part of nftlb, nftables load balancer.
  *
- *   Copyright (C) ZEVENET SL.
- *   Author: Laura Garcia <laura.garcia@zevenet.com>
+ *   Copyright (C) RELIANOID
+ *   Author: Laura Garcia Liebana <laura@relianoid.com>
  *
  *   This program is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU Affero General Public License as
@@ -30,7 +30,7 @@
 #include "objects.h"
 #include "network.h"
 #include "sessions.h"
-#include "zcu_log.h"
+#include "u_log.h"
 
 #define BACKEND_MARK_MIN			0x00000001
 #define BACKEND_MARK_MAX			0x00000FFF
@@ -67,7 +67,7 @@ static struct backend * backend_create(struct farm *f, char *name)
 {
 	struct backend *b = (struct backend *)malloc(sizeof(struct backend));
 	if (!b) {
-		zcu_log_print(LOG_ERR, "Backend memory allocation error");
+		u_log_print(LOG_ERR, "Backend memory allocation error");
 		return NULL;
 	}
 
@@ -126,7 +126,7 @@ static int backend_below_prio(struct backend *b)
 {
 	struct farm *f = b->parent;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d <= farm prio %d",
+	u_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d <= farm prio %d",
 				   __FUNCTION__, __LINE__, b->name, obj_print_state(b->state), b->priority, f->priority);
 
 	return (b->priority <= f->priority);
@@ -136,7 +136,7 @@ static int backend_s_set_ports(struct farm *f)
 {
 	struct backend *b;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: finding backends with port for %s", __FUNCTION__, __LINE__, f->name);
+	u_log_print(LOG_DEBUG, "%s():%d: finding backends with port for %s", __FUNCTION__, __LINE__, f->name);
 
 	list_for_each_entry(b, &f->backends, list) {
 		if (strcmp(b->port, DEFAULT_PORT) == 0) {
@@ -181,38 +181,38 @@ void backend_s_print(struct farm *f)
 	struct backend *b;
 
 	list_for_each_entry(b, &f->backends, list) {
-		zcu_log_print(LOG_DEBUG,"    [backend] ");
-		zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_NAME, b->name);
+		u_log_print(LOG_DEBUG,"    [backend] ");
+		u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_NAME, b->name);
 
 		if (b->fqdn)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_FQDN, b->fqdn);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_FQDN, b->fqdn);
 
 		if (b->oface)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_OFACE, b->oface);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_OFACE, b->oface);
 
-		zcu_log_print(LOG_DEBUG,"      *[ofidx] %d", b->ofidx);
+		u_log_print(LOG_DEBUG,"      *[ofidx] %d", b->ofidx);
 
 		if (b->ipaddr)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_IPADDR, b->ipaddr);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_IPADDR, b->ipaddr);
 
 		if (b->ethaddr)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_ETHADDR, b->ethaddr);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_ETHADDR, b->ethaddr);
 
 		if (b->port)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_PORT, b->port);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_PORT, b->port);
 
 		if (b->srcaddr)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_SRCADDR, b->srcaddr);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_SRCADDR, b->srcaddr);
 
-		zcu_log_print(LOG_DEBUG,"       [%s] 0x%x", CONFIG_KEY_MARK, b->mark);
-		zcu_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_ESTCONNLIMIT, b->estconnlimit);
+		u_log_print(LOG_DEBUG,"       [%s] 0x%x", CONFIG_KEY_MARK, b->mark);
+		u_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_ESTCONNLIMIT, b->estconnlimit);
 		if (b->estconnlimit_logprefix && strcmp(b->estconnlimit_logprefix, DEFAULT_B_ESTCONNLIMIT_LOGPREFIX) != 0)
-			zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_ESTCONNLIMIT_LOGPREFIX, b->estconnlimit_logprefix);
+			u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_ESTCONNLIMIT_LOGPREFIX, b->estconnlimit_logprefix);
 
-		zcu_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_WEIGHT, b->weight);
-		zcu_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_PRIORITY, b->priority);
-		zcu_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_STATE, obj_print_state(b->state));
-		zcu_log_print(LOG_DEBUG,"      *[%s] %d", CONFIG_KEY_ACTION, b->action);
+		u_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_WEIGHT, b->weight);
+		u_log_print(LOG_DEBUG,"       [%s] %d", CONFIG_KEY_PRIORITY, b->priority);
+		u_log_print(LOG_DEBUG,"       [%s] %s", CONFIG_KEY_STATE, obj_print_state(b->state));
+		u_log_print(LOG_DEBUG,"      *[%s] %d", CONFIG_KEY_ACTION, b->action);
 	}
 }
 
@@ -220,7 +220,7 @@ struct backend * backend_lookup_by_key(struct farm *f, int key, const char *name
 {
 	struct backend *b;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: farm %s key %d name %s value %d", __FUNCTION__, __LINE__, f->name, key, name, value);
+	u_log_print(LOG_DEBUG, "%s():%d: farm %s key %d name %s value %d", __FUNCTION__, __LINE__, f->name, key, name, value);
 
 	list_for_each_entry(b, &f->backends, list) {
 		switch (key) {
@@ -265,7 +265,7 @@ static int backend_set_ipaddr_from_ether(struct backend *b)
 
 	fa = farmaddress_get_first(f);
 	if (!fa) {
-		zcu_log_print(LOG_INFO, "%s():%d: no farm address configured in %s", __FUNCTION__, __LINE__, f->name);
+		u_log_print(LOG_INFO, "%s():%d: no farm address configured in %s", __FUNCTION__, __LINE__, f->name);
 		return -1;
 	}
 
@@ -305,7 +305,7 @@ static int backend_set_ipaddr_from_ether(struct backend *b)
 		sprintf(streth, "%02x:%02x:%02x:%02x:%02x:%02x", dst_ethaddr[0],
 			dst_ethaddr[1], dst_ethaddr[2], dst_ethaddr[3], dst_ethaddr[4], dst_ethaddr[5]);
 
-		zcu_log_print(LOG_DEBUG, "%s():%d: discovered ether address for %s is %s", __FUNCTION__, __LINE__, b->name, streth);
+		u_log_print(LOG_DEBUG, "%s():%d: discovered ether address for %s is %s", __FUNCTION__, __LINE__, b->name, streth);
 
 		if (b->ethaddr)
 			free(b->ethaddr);
@@ -320,7 +320,7 @@ static int backend_set_weight(struct backend *b, int new_value)
 	struct farm *f = b->parent;
 	int old_value = b->weight;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	b->weight = new_value;
@@ -335,7 +335,7 @@ static int backend_set_estconnlimit(struct backend *b, int new_value)
 {
 	int old_value = b->estconnlimit;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	if (new_value == old_value)
@@ -350,7 +350,7 @@ static void backend_s_update_counters(struct farm *f)
 {
 	struct backend *bp, *next;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: farm %s", __FUNCTION__, __LINE__, f->name);
+	u_log_print(LOG_DEBUG, "%s():%d: farm %s", __FUNCTION__, __LINE__, f->name);
 
 	f->bcks_available = 0;
 	f->bcks_usable = 0;
@@ -370,7 +370,7 @@ static int backend_set_priority(struct backend *b, int new_value)
 {
 	int old_value = b->priority;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	if (new_value <= 0)
@@ -386,7 +386,7 @@ static int backend_s_set_srcaddr(struct farm *f)
 {
 	struct backend *b;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: finding backends with srouce address for %s", __FUNCTION__, __LINE__, f->name);
+	u_log_print(LOG_DEBUG, "%s():%d: finding backends with srouce address for %s", __FUNCTION__, __LINE__, f->name);
 
 	list_for_each_entry(b, &f->backends, list) {
 		if (b->srcaddr && strcmp(b->srcaddr, "") != 0) {
@@ -406,7 +406,7 @@ static int backend_set_mark(struct backend *b, int new_value)
 	if (new_value < BACKEND_MARK_MIN || new_value > BACKEND_MARK_MAX)
 		return 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %d, but new value will be %d",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	b->mark = new_value;
@@ -418,7 +418,7 @@ static int backend_set_port(struct backend *b, char *new_value)
 {
 	char *old_value = b->port;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	if (strcmp(b->port, DEFAULT_PORT) != 0)
@@ -438,7 +438,7 @@ static int backend_set_srcaddr(struct backend *b, char *new_value)
 {
 	char *old_value = b->srcaddr;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	if (b->srcaddr)
@@ -460,25 +460,25 @@ static int backend_set_ifinfo(struct backend *b)
 	int if_index;
 	int ret = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: backend %s set interface info", __FUNCTION__, __LINE__, b->name);
+	u_log_print(LOG_DEBUG, "%s():%d: backend %s set interface info", __FUNCTION__, __LINE__, b->name);
 
 	if (!farm_is_ingress_mode(f) || (f->state != VALUE_STATE_UP && f->state != VALUE_STATE_CONFERR))
 		return 0;
 
 	if (f->oface && strcmp(f->oface, IFACE_LOOPBACK) == 0) {
-		zcu_log_print(LOG_DEBUG, "%s():%d: backend %s in farm %s doesn't require output netinfo, loopback interface", __FUNCTION__, __LINE__, b->name, f->name);
+		u_log_print(LOG_DEBUG, "%s():%d: backend %s in farm %s doesn't require output netinfo, loopback interface", __FUNCTION__, __LINE__, b->name, f->name);
 		f->ofidx = 0;
 		return 0;
 	}
 
 	if (!b || b->ipaddr == DEFAULT_IPADDR) {
-		zcu_log_print(LOG_ERR, "%s():%d: there is no backend yet in the farm %s", __FUNCTION__, __LINE__, f->name);
+		u_log_print(LOG_ERR, "%s():%d: there is no backend yet in the farm %s", __FUNCTION__, __LINE__, f->name);
 		return 0;
 	}
 
 	ret = net_get_local_ifidx_per_remote_host(b->ipaddr, &if_index);
 	if (ret == -1) {
-		zcu_log_print(LOG_ERR, "%s():%d: unable to get the outbound interface to %s for the backend %s in farm %s", __FUNCTION__, __LINE__, b->ipaddr, b->name, f->name);
+		u_log_print(LOG_ERR, "%s():%d: unable to get the outbound interface to %s for the backend %s in farm %s", __FUNCTION__, __LINE__, b->ipaddr, b->name, f->name);
 		return -1;
 	}
 
@@ -491,7 +491,7 @@ static int backend_set_ifinfo(struct backend *b)
 	}
 
 	if (if_indextoname(if_index, if_str) == NULL) {
-		zcu_log_print(LOG_ERR, "%s():%d: unable to get the outbound interface name with index %d required by the backend %s in farm %s", __FUNCTION__, __LINE__, if_index, b->name, f->name);
+		u_log_print(LOG_ERR, "%s():%d: unable to get the outbound interface name with index %d required by the backend %s in farm %s", __FUNCTION__, __LINE__, if_index, b->name, f->name);
 		return -1;
 	}
 
@@ -515,7 +515,7 @@ static int backend_set_ipaddr(struct backend *b, char *new_value)
 	char *old_value = b->ipaddr;
 	int netconfig;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
+	u_log_print(LOG_DEBUG, "%s():%d: current value is %s, but new value will be %s",
 				   __FUNCTION__, __LINE__, old_value, new_value);
 
 	if (b->ipaddr)
@@ -541,7 +541,7 @@ static int backend_set_ipaddr(struct backend *b, char *new_value)
 
 int backend_is_usable(struct backend *b)
 {
-	zcu_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d",
+	u_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d",
 				   __FUNCTION__, __LINE__, b->name, obj_print_state(b->state), b->priority);
 
 	return ((b->state == VALUE_STATE_UP || b->state == VALUE_STATE_OFF) && backend_below_prio(b));
@@ -562,7 +562,7 @@ int backend_changed(struct config_pair *c)
 	if (!f || !b)
 		return -1;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: farm %s backend %s with param %d", __FUNCTION__, __LINE__, f->name, b->name, c->key);
+	u_log_print(LOG_DEBUG, "%s():%d: farm %s backend %s with param %d", __FUNCTION__, __LINE__, f->name, b->name, c->key);
 
 	switch (c->key) {
 	case KEY_NAME:
@@ -618,7 +618,7 @@ int backend_validate(struct backend *b)
 {
 	struct farm *f = b->parent;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: validating backend %s of farm %s",
+	u_log_print(LOG_DEBUG, "%s():%d: validating backend %s of farm %s",
 				   __FUNCTION__, __LINE__, b->name, f->name);
 
 	if (farm_is_ingress_mode(f) &&
@@ -633,7 +633,7 @@ int backend_validate(struct backend *b)
 
 int backend_is_available(struct backend *b)
 {
-	zcu_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d",
+	u_log_print(LOG_DEBUG, "%s():%d: backend %s state is %s and priority %d",
 				   __FUNCTION__, __LINE__, b->name, obj_print_state(b->state), b->priority);
 
 	return (backend_validate(b) && (b->state == VALUE_STATE_UP) && backend_below_prio(b));
@@ -643,7 +643,7 @@ int backend_set_action(struct backend *b, int action)
 {
 	int is_actionated = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: bck %s action %d state %d - new action %d",
+	u_log_print(LOG_DEBUG, "%s():%d: bck %s action %d state %d - new action %d",
 				   __FUNCTION__, __LINE__, b->name, b->action, b->state, action);
 
 	if (action == ACTION_DELETE) {
@@ -797,7 +797,7 @@ int backend_set_state(struct backend *b, int new_value)
 	int old_value = b->state;
 	struct farm *f = b->parent;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: backend %s current value is %s, but new value will be %s",
+	u_log_print(LOG_DEBUG, "%s():%d: backend %s current value is %s, but new value will be %s",
 				   __FUNCTION__, __LINE__, b->name, obj_print_state(old_value), obj_print_state(new_value));
 
 	if (new_value == VALUE_STATE_UP) {
@@ -863,7 +863,7 @@ int backend_s_set_ether_by_ipaddr(struct farm *f, const char *ip_bck, char *ethe
 		if (strcmp(b->ipaddr, ip_bck) != 0)
 			continue;
 
-		zcu_log_print(LOG_DEBUG, "%s():%d: backend with ip address %s found", __FUNCTION__, __LINE__, ip_bck);
+		u_log_print(LOG_DEBUG, "%s():%d: backend with ip address %s found", __FUNCTION__, __LINE__, ip_bck);
 
 		if (!b->ethaddr || (b->ethaddr && strcmp(b->ethaddr, ether_bck) != 0)) {
 			if (f->persistence != VALUE_META_NONE)
@@ -879,7 +879,7 @@ int backend_s_set_ether_by_ipaddr(struct farm *f, const char *ip_bck, char *ethe
 				session_s_delete(f, SESSION_TYPE_TIMED);
 			}
 
-			zcu_log_print(LOG_INFO, "%s():%d: ether address changed for backend %s with %s", __FUNCTION__, __LINE__, b->name, ether_bck);
+			u_log_print(LOG_INFO, "%s():%d: ether address changed for backend %s with %s", __FUNCTION__, __LINE__, b->name, ether_bck);
 		}
 	}
 
@@ -900,7 +900,7 @@ int backend_s_set_netinfo(struct farm *f)
 	struct backend *b;
 	int changed = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: finding backends for %s", __FUNCTION__, __LINE__, f->name);
+	u_log_print(LOG_DEBUG, "%s():%d: finding backends for %s", __FUNCTION__, __LINE__, f->name);
 
 	list_for_each_entry(b, &f->backends, list) {
 		if (backend_validate(b))
@@ -927,7 +927,7 @@ int bck_pre_actionable(struct config_pair *c)
 	if (!f || !b)
 		return -1;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: pre actionable backend %s of farm %s with param %d", __FUNCTION__, __LINE__, b->name, f->name, c->key);
+	u_log_print(LOG_DEBUG, "%s():%d: pre actionable backend %s of farm %s with param %d", __FUNCTION__, __LINE__, b->name, f->name, c->key);
 
 	// changing priority of a down backend could affect others, force a farm restart
 	if (b->state != VALUE_STATE_UP && b->state != VALUE_STATE_CONFERR && c->key == KEY_PRIORITY) {
@@ -980,7 +980,7 @@ int bck_pos_actionable(struct config_pair *c, int action)
 	if (!f || !b)
 		return -1;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: pos actionable backend %s of farm %s with param %d action %d", __FUNCTION__, __LINE__, b->name, f->name, c->key, action);
+	u_log_print(LOG_DEBUG, "%s():%d: pos actionable backend %s of farm %s with param %d action %d", __FUNCTION__, __LINE__, b->name, f->name, c->key, action);
 
 	switch (action) {
 	case ACTION_START:
