@@ -1,8 +1,8 @@
 /*
  *   This file is part of nftlb, nftables load balancer.
  *
- *   Copyright (C) ZEVENET SL.
- *   Author: Laura Garcia <laura.garcia@zevenet.com>
+ *   Copyright (C) RELIANOID
+ *   Author: Laura Garcia Liebana <laura@relianoid.com>
  *
  *   This program is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU Affero General Public License as
@@ -38,7 +38,7 @@
 #include "events.h"
 #include "farms.h"
 #include "checksum.h"
-#include "zcu_log.h"
+#include "u_log.h"
 
 #define ARP_TABLE_RETRY_SLEEP		1000
 #define ICMP_PROTO					1
@@ -129,7 +129,7 @@ static int send_ping(void *data)
 	int *frame_len;
 	uint8_t *frame;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: sending ping", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: sending ping", __FUNCTION__, __LINE__);
 
 	if (sdata->family == AF_INET6) {
 		frame_len = &frame_len_v6;
@@ -204,19 +204,19 @@ static int send_ping(void *data)
 	}
 
 	if (sock < 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: open socket error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: open socket error", __FUNCTION__, __LINE__);
 		ret = -1;
 		goto out;
 	}
 
 	if (sendto(sock, frame, *frame_len, 0, pdevice, sizeof(device)) <= 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: sendto error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: sendto error", __FUNCTION__, __LINE__);
 		ret = -1;
 	}
 
 out:
 	if (ret && sock > 0) {
-		zcu_log_print(LOG_DEBUG, "%s():%d: cleanup socket", __FUNCTION__, __LINE__);
+		u_log_print(LOG_DEBUG, "%s():%d: cleanup socket", __FUNCTION__, __LINE__);
 		close(sock);
 	}
 
@@ -228,7 +228,7 @@ static int data_attr_neigh_cb(const struct nlattr *attr, void *data)
 	const struct nlattr **tb = data;
 	int type = mnl_attr_get_type(attr);
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: launched cb neighbour", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: launched cb neighbour", __FUNCTION__, __LINE__);
 
 	if (mnl_attr_type_valid(attr, NDA_MAX) < 0)
 		return MNL_CB_OK;
@@ -237,7 +237,7 @@ static int data_attr_neigh_cb(const struct nlattr *attr, void *data)
 	case NDA_DST:
 	case NDA_LLADDR:
 		if (mnl_attr_validate(attr, MNL_TYPE_BINARY) < 0) {
-			zcu_log_print(LOG_ERR, "%s():%d: mnl_attr_validate error", __FUNCTION__, __LINE__);
+			u_log_print(LOG_ERR, "%s():%d: mnl_attr_validate error", __FUNCTION__, __LINE__);
 			return MNL_CB_ERROR;
 		}
 		break;
@@ -260,7 +260,7 @@ static int data_getdst_neigh_cb(const struct nlmsghdr *nlh, void *data)
 	struct ntl_data *sdata = data;
 	int matches = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: getting ethernet address destination", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: getting ethernet address destination", __FUNCTION__, __LINE__);
 
 	mnl_attr_parse(nlh, sizeof(*ndm), data_attr_neigh_cb, tb);
 
@@ -279,7 +279,7 @@ static int data_getdst_neigh_cb(const struct nlmsghdr *nlh, void *data)
 			ethaddr = mnl_attr_get_payload(tb[NDA_LLADDR]);
 			memcpy(&sdata->dst_ethaddr, ethaddr, 6);
 
-			zcu_log_print(LOG_INFO, "%s():%d: get ether address index=%d family=%d dst=%s eth=%02x:%02x:%02x:%02x:%02x:%02x sts=%d",
+			u_log_print(LOG_INFO, "%s():%d: get ether address index=%d family=%d dst=%s eth=%02x:%02x:%02x:%02x:%02x:%02x sts=%d",
 						   __FUNCTION__, __LINE__,
 						   ndm->ndm_ifindex, ndm->ndm_family, out, sdata->dst_ethaddr[0],
 						   sdata->dst_ethaddr[1], sdata->dst_ethaddr[2], sdata->dst_ethaddr[3],
@@ -297,7 +297,7 @@ static int data_route_attr_cb(const struct nlattr *attr, void *data)
 	const struct nlattr **tb = data;
 	int type = mnl_attr_get_type(attr);
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: route netlink attr", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: route netlink attr", __FUNCTION__, __LINE__);
 
 	if (mnl_attr_type_valid(attr, RTA_MAX) < 0)
 		return MNL_CB_OK;
@@ -312,13 +312,13 @@ static int data_getdst_route_cb(const struct nlmsghdr *nlh, void *data)
 	struct rtmsg *rm = mnl_nlmsg_get_payload(nlh);
 	struct ntl_data *sdata = data;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: getting interface route destination", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: getting interface route destination", __FUNCTION__, __LINE__);
 
 	mnl_attr_parse(nlh, sizeof(*rm), data_route_attr_cb, tb);
 
 	if (tb[RTA_OIF]) {
 		sdata->oifidx = mnl_attr_get_u32(tb[RTA_OIF]);
-		zcu_log_print(LOG_INFO, "%s():%d: get routing interface to destination is %u", __FUNCTION__, __LINE__, sdata->oifidx);
+		u_log_print(LOG_INFO, "%s():%d: get routing interface to destination is %u", __FUNCTION__, __LINE__, sdata->oifidx);
 		return MNL_CB_STOP;
 	}
 
@@ -329,22 +329,22 @@ static int ntl_request(struct ntl_request *ntl)
 {
 	int ret, out = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: launch netlink request", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: launch netlink request", __FUNCTION__, __LINE__);
 
 	ntl->nl = mnl_socket_open(NETLINK_ROUTE);
 	if (ntl->nl == NULL) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_open error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_open error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
 	if (mnl_socket_bind(ntl->nl, 0, MNL_SOCKET_AUTOPID) < 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_bind error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_bind error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 	ntl->portid = mnl_socket_get_portid(ntl->nl);
 
 	if (mnl_socket_sendto(ntl->nl, ntl->nlh, ntl->nlh->nlmsg_len) < 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_sendto error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_sendto error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
@@ -362,7 +362,7 @@ static int ntl_request(struct ntl_request *ntl)
 	}
 
 	if (ret == -1) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_recvfrom error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_recvfrom error", __FUNCTION__, __LINE__);
 		ret = -1;
 	}
 
@@ -378,7 +378,7 @@ int net_get_neigh_ether(unsigned char **dst_ethaddr, unsigned char *src_ethaddr,
 	struct ntl_data *data;
 	int ret = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: source mac address %s source ip address %s destination ip address %s iface %d", __FUNCTION__, __LINE__, src_ethaddr, src_ipaddr, dst_ipaddr, outdev);
+	u_log_print(LOG_DEBUG, "%s():%d: source mac address %s source ip address %s destination ip address %s iface %d", __FUNCTION__, __LINE__, src_ethaddr, src_ipaddr, dst_ipaddr, outdev);
 
 	ntl.buf = (char *) malloc(MNL_SOCKET_BUFFER_SIZE);
 
@@ -391,13 +391,13 @@ int net_get_neigh_ether(unsigned char **dst_ethaddr, unsigned char *src_ethaddr,
 	ntl.rt->rtgen_family = GET_AF_INET(family);
 	ntl.cb = data_getdst_neigh_cb;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: source ether is %02x:%02x:%02x:%02x:%02x:%02x",
+	u_log_print(LOG_DEBUG, "%s():%d: source ether is %02x:%02x:%02x:%02x:%02x:%02x",
 				   __FUNCTION__, __LINE__, src_ethaddr[0], src_ethaddr[1], src_ethaddr[2],
 				   src_ethaddr[3], src_ethaddr[4], src_ethaddr[5]);
 
 	data = (struct ntl_data *)calloc(1, sizeof(struct ntl_data));
 	if (!data) {
-		zcu_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
@@ -405,14 +405,14 @@ int net_get_neigh_ether(unsigned char **dst_ethaddr, unsigned char *src_ethaddr,
 
 	data->dst_ipaddr = (struct in6_addr *)calloc(1, sizeof(struct in6_addr));
 	if (!data->dst_ipaddr){
-		zcu_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
 	data->family = GET_AF_INET(family);
 
 	if (inet_pton(data->family, dst_ipaddr, data->dst_ipaddr) <= 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, dst_ipaddr);
+		u_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, dst_ipaddr);
 		return -1;
 	}
 
@@ -422,16 +422,16 @@ int net_get_neigh_ether(unsigned char **dst_ethaddr, unsigned char *src_ethaddr,
 
 	if (ret != 0) {
 		ret = -1;
-		zcu_log_print(LOG_DEBUG, "%s():%d: not found, send ping to %s", __FUNCTION__, __LINE__, dst_ipaddr);
+		u_log_print(LOG_DEBUG, "%s():%d: not found, send ping to %s", __FUNCTION__, __LINE__, dst_ipaddr);
 
 		data->src_ipaddr = (struct in6_addr *)calloc(1, sizeof(struct in6_addr));
 		if (!data->src_ipaddr){
-			zcu_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
+			u_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
 			return ret;
 		}
 
 		if (inet_pton(data->family, src_ipaddr, data->src_ipaddr) <= 0) {
-			zcu_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, src_ipaddr);
+			u_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, src_ipaddr);
 			return ret;
 		}
 
@@ -456,7 +456,7 @@ int net_get_local_ifidx_per_remote_host(char *dst_ipaddr, int *outdev)
 	int ipv = net_get_addr_family(dst_ipaddr);
 	int ret = 0;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: dst ip address is %s", __FUNCTION__, __LINE__, dst_ipaddr);
+	u_log_print(LOG_DEBUG, "%s():%d: dst ip address is %s", __FUNCTION__, __LINE__, dst_ipaddr);
 
 	ntl.buf = (char *) malloc(MNL_SOCKET_BUFFER_SIZE);
 
@@ -478,13 +478,13 @@ int net_get_local_ifidx_per_remote_host(char *dst_ipaddr, int *outdev)
 
 	data = (struct ntl_data *)calloc(1, sizeof(struct ntl_data));
 	if (!data) {
-		zcu_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
 	data->dst_ipaddr = (struct in6_addr *)calloc(1, sizeof(struct in6_addr));
 	if (!data->dst_ipaddr){
-		zcu_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: memory allocation error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
@@ -493,7 +493,7 @@ int net_get_local_ifidx_per_remote_host(char *dst_ipaddr, int *outdev)
 	data->family = ipv;
 
 	if (!inet_pton(ipv, dst_ipaddr, &(addr.sin6_addr.s6_addr))) {
-		zcu_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, dst_ipaddr);
+		u_log_print(LOG_ERR, "%s():%d: network translation error for %s", __FUNCTION__, __LINE__, dst_ipaddr);
 		return -1;
 	}
 
@@ -502,11 +502,11 @@ int net_get_local_ifidx_per_remote_host(char *dst_ipaddr, int *outdev)
 	ret = ntl_request(&ntl);
 
 	if (ret != 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: not found route to %s", __FUNCTION__, __LINE__, dst_ipaddr);
+		u_log_print(LOG_ERR, "%s():%d: not found route to %s", __FUNCTION__, __LINE__, dst_ipaddr);
 		return -1;
 	}
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: found route to %s via %d", __FUNCTION__, __LINE__, dst_ipaddr, data->oifidx);
+	u_log_print(LOG_DEBUG, "%s():%d: found route to %s via %d", __FUNCTION__, __LINE__, dst_ipaddr, data->oifidx);
 
 	*outdev = data->oifidx;
 
@@ -523,19 +523,19 @@ int net_get_local_ifinfo(unsigned char **ether, const char *indev)
 	struct ifreq ifr;
 	int sd;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: netlink get local interface info for %s", __FUNCTION__, __LINE__, indev);
+	u_log_print(LOG_DEBUG, "%s():%d: netlink get local interface info for %s", __FUNCTION__, __LINE__, indev);
 
 	sd = socket(AF_PACKET, SOCK_RAW, IPPROTO_RAW);
 
 	if (sd <= 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: open socket error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: open socket error", __FUNCTION__, __LINE__);
 		goto out;
 	}
 
 	strcpy(ifr.ifr_name, indev);
 
 	if (ioctl(sd, SIOCGIFHWADDR, &ifr) == -1) {
-		zcu_log_print(LOG_ERR, "%s():%d: ioctl SIOCGIFHWADDR error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: ioctl SIOCGIFHWADDR error", __FUNCTION__, __LINE__);
 		goto out;
 	}
 
@@ -558,17 +558,17 @@ int net_get_local_ifname_per_vip(char *strvip, char *outdev)
 	struct sockaddr_in6 *ipaddr6;
 	struct ifaddrs *ifaddrs, *ifaddr;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: netlink get local interface name for %s", __FUNCTION__, __LINE__, strvip);
+	u_log_print(LOG_DEBUG, "%s():%d: netlink get local interface name for %s", __FUNCTION__, __LINE__, strvip);
 
 	if (!strvip || strcmp(strvip, "") == 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: vip is not set yet", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: vip is not set yet", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
 	ipv = net_get_addr_family(strvip);
 
 	if (getifaddrs(&ifaddrs) == -1) {
-		zcu_log_print(LOG_ERR, "%s():%d: cannot get interfaces list", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: cannot get interfaces list", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
@@ -601,7 +601,7 @@ int net_get_local_ifname_per_vip(char *strvip, char *outdev)
 
 	freeifaddrs(ifaddrs);
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: netlink get local interface name is %s", __FUNCTION__, __LINE__, outdev);
+	u_log_print(LOG_DEBUG, "%s():%d: netlink get local interface name is %s", __FUNCTION__, __LINE__, outdev);
 
 	return !found;
 }
@@ -616,7 +616,7 @@ static int data_getev_cb(const struct nlmsghdr *nlh, void *data)
 	unsigned char dst_ethaddr[ETH_HW_ADDR_LEN];
 	char streth[ETH_HW_STR_LEN] = {};
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: netlink read new info", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: netlink read new info", __FUNCTION__, __LINE__);
 
 	if (nlh->nlmsg_type != RTM_NEWNEIGH)
 		return MNL_CB_STOP;
@@ -638,7 +638,7 @@ static int data_getev_cb(const struct nlmsghdr *nlh, void *data)
 		if ((ndm->ndm_state & NUD_REACHABLE) || (ndm->ndm_state & NUD_PERMANENT) || (ndm->ndm_state & NUD_STALE))
 			farm_s_set_backend_ether_by_oifidx(ndm->ndm_ifindex, str_ipaddr, streth);
 
-		zcu_log_print(LOG_DEBUG, "%s():%d: [NEW NEIGH] family=%u ifindex=%u state=%u dstaddr=%s macaddr=%s",
+		u_log_print(LOG_DEBUG, "%s():%d: [NEW NEIGH] family=%u ifindex=%u state=%u dstaddr=%s macaddr=%s",
 					   __FUNCTION__, __LINE__, ndm->ndm_family, ndm->ndm_ifindex, ndm->ndm_state, str_ipaddr,
 					   streth);
 	}
@@ -651,7 +651,7 @@ static void ntlk_cb(struct ev_loop *loop, struct ev_io *watcher, int revents)
 	char buf[MNL_SOCKET_BUFFER_SIZE];
 	int ret, out;
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: netlink callback executed", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: netlink callback executed", __FUNCTION__, __LINE__);
 
 	ret = mnl_socket_recvfrom(nl, buf, sizeof(buf));
 	while (ret > 0) {
@@ -666,7 +666,7 @@ static void ntlk_cb(struct ev_loop *loop, struct ev_io *watcher, int revents)
 	}
 
 	if (ret == -1) {
-		zcu_log_print(LOG_ERR, "%s():%d: netlink error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: netlink error", __FUNCTION__, __LINE__);
 		ret = -1;
 	}
 }
@@ -677,7 +677,7 @@ int net_eventd_init(void)
 	int sock;
 	struct ev_loop *st_ev_loop = get_loop();
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: net eventd launched", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: net eventd launched", __FUNCTION__, __LINE__);
 
 	io_handle.io = events_create_ntlnk();
 
@@ -691,14 +691,14 @@ int net_eventd_init(void)
 
 	nl = mnl_socket_open(NETLINK_ROUTE);
 	if (nl == NULL) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_open error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_open error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
 	sock = mnl_socket_get_fd(nl);
 
 	if (mnl_socket_bind(nl, RTM_GETNEIGH, MNL_SOCKET_AUTOPID) < 0) {
-		zcu_log_print(LOG_ERR, "%s():%d: mnl_socket_bind error", __FUNCTION__, __LINE__);
+		u_log_print(LOG_ERR, "%s():%d: mnl_socket_bind error", __FUNCTION__, __LINE__);
 		return -1;
 	}
 
@@ -714,7 +714,7 @@ int net_eventd_stop(void)
 {
 	struct ev_loop *st_ev_loop = get_loop();
 
-	zcu_log_print(LOG_DEBUG, "%s():%d: net eventd stopped", __FUNCTION__, __LINE__);
+	u_log_print(LOG_DEBUG, "%s():%d: net eventd stopped", __FUNCTION__, __LINE__);
 
 	ev_io_stop(st_ev_loop, io_handle.io);
 	mnl_socket_close(nl);
@@ -729,7 +729,7 @@ int net_eventd_stop(void)
 
 int net_get_event_enabled(void)
 {
-	zcu_log_print(LOG_DEBUG, "%s():%d: net eventd is %d", __FUNCTION__, __LINE__, net_event_enabled);
+	u_log_print(LOG_DEBUG, "%s():%d: net eventd is %d", __FUNCTION__, __LINE__, net_event_enabled);
 	return net_event_enabled;
 }
 
