@@ -1,8 +1,8 @@
 /*
  *   This file is part of nftlb, nftables load balancer.
  *
- *   Copyright (C) ZEVENET SL.
- *   Author: Laura Garcia <laura.garcia@zevenet.com>
+ *   Copyright (C) RELIANOID
+ *   Author: Laura Garcia Liebana <laura@relianoid.com>
  *
  *   This program is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU Affero General Public License as
@@ -20,6 +20,7 @@
  */
 
 #include <stdio.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -34,9 +35,9 @@
 #include "config.h"
 #include "nft.h"
 #include "events.h"
-#include "zcu_sbuffer.h"
-#include "zcu_log.h"
-#include "zcu_http.h"
+#include "u_sbuffer.h"
+#include "u_log.h"
+#include "u_http.h"
 
 #define SRV_MAX_BUF				1024
 #define SRV_MAX_HEADER			300
@@ -100,12 +101,42 @@ static int parse_to_http_status(int code)
 	}
 }
 
-static int auth_key(const char *recvkey)
+/*
+	Check for strings equality in constant time.
+	Taken from <https://nachtimwald.com/2017/04/02/constant-time-string-comparison-in-c/>
+*/
+static bool str_iseq(const char *s1, const char *s2)
 {
-	return (strcmp(nftserver.key, recvkey) == 0);
+	int m = 0;
+	volatile size_t i = 0;
+	volatile size_t j = 0;
+	volatile size_t k = 0;
+
+	if (s1 == NULL || s2 == NULL)
+		return false;
+
+	while (true) {
+		m |= s1[i] ^ s2[j];
+
+		if (s1[i] == '\0')
+			break;
+		i++;
+
+		if (s2[j] != '\0')
+			j++;
+		if (s2[j] == '\0')
+			k++;
+	}
+
+	return m == 0;
 }
 
-static int get_request(int fd, struct zcu_buffer *buf, struct nftlb_http_state *state)
+static bool auth_key(const char *recvkey)
+{
+	return str_iseq(nftserver.key, recvkey);
+}
+
+static int get_request(int fd, struct u_buffer *buf, struct nftlb_http_state *state)
 {
 	char method[SRV_MAX_IDENT] = {0};
 	char strkey[SRV_MAX_IDENT] = {0};
@@ -118,7 +149,7 @@ static int get_request(int fd, struct zcu_buffer *buf, struct nftlb_http_state *
 	int bytes_left;
 	int cont_100 = 0;
 
-	if ((ptr = strstr(zcu_buf_get_data(buf), "Key: ")) == NULL) {
+	if ((ptr = strstr(u_buf_get_data(buf), "Key: ")) == NULL) {
 		state->status_code = WS_HTTP_401;
 		return -1;
 	}
@@ -130,9 +161,9 @@ static int get_request(int fd, struct zcu_buffer *buf, struct nftlb_http_state *
 		return -1;
 	}
 
-	sscanf(zcu_buf_get_data(buf), "%199[^ ] %199[^ ] ", method, state->uri);
+	sscanf(u_buf_get_data(buf), "%199[^ ] %199[^ ] ", method, state->uri);
 
-	zcu_log_print(LOG_NOTICE, "%s():%d: request: %s %s", __FUNCTION__, __LINE__, method, state->uri);
+	u_log_print(LOG_NOTICE, "%s():%d: request: %s %s", __FUNCTION__, __LINE__, method, state->uri);
 
 	if (strncmp(method, STR_GET_ACTION, 4) == 0) {
 		state->method = WS_GET_ACTION;
@@ -152,38 +183,38 @@ static int get_request(int fd, struct zcu_buffer *buf, struct nftlb_http_state *
 	if (state->method == WS_GET_ACTION)
 		return 0;
 
-	state->body = strstr(zcu_buf_get_data(buf), "\r\n\r\n");
+	state->body = strstr(u_buf_get_data(buf), "\r\n\r\n");
 	if (!state->body) {
-		zcu_log_print(LOG_ERR, "Not found body section in the request");
+		u_log_print(LOG_ERR, "Not found body section in the request");
 		state->status_code = parse_to_http_status(PARSER_STRUCT_FAILED);
 		return -1;
 	}
 	state->body += 4;
-	head = state->body - zcu_buf_get_data(buf);
+	head = state->body - u_buf_get_data(buf);
 
-	if ((ptr = strstr(zcu_buf_get_data(buf), "Expect: 100-continue")) != NULL) {
+	if ((ptr = strstr(u_buf_get_data(buf), "Expect: 100-continue")) != NULL) {
 		cont_100 = 1;
 		send(fd, "HTTP/1.1 100 Continue\r\n\r\n", 25, 0);
 	}
 
-	if ((ptr = strstr(zcu_buf_get_data(buf), "Content-Length: ")) != NULL) {
+	if ((ptr = strstr(u_buf_get_data(buf), "Content-Length: ")) != NULL) {
 		sscanf(ptr, "Content-Length: %i[^\r\n]", &contlength);
 
-		if (head + contlength >= zcu_buf_get_size(buf))
-			times = ((head + contlength - zcu_buf_get_size(buf)) / EXTRA_SIZE) + 1;
+		if (head + contlength >= u_buf_get_size(buf))
+			times = ((head + contlength - u_buf_get_size(buf)) / EXTRA_SIZE) + 1;
 		if (times == 0)
 			goto receive;
 
-		if (zcu_buf_resize(buf, times)) {
-			zcu_log_print(LOG_ERR, "Error resizing the buffer %d times from a size of %d!", times, zcu_buf_get_size(buf));
+		if (u_buf_resize(buf, times)) {
+			u_log_print(LOG_ERR, "Error resizing the buffer %d times from a size of %d!", times, u_buf_get_size(buf));
 			state->status_code = WS_HTTP_500;
 			return -1;
 		}
 	}
 
 receive:
-	state->body = zcu_buf_get_data(buf) + head;
-	total_read_size = zcu_buf_get_next(buf) - state->body;
+	state->body = u_buf_get_data(buf) + head;
+	total_read_size = u_buf_get_next(buf) - state->body;
 	while ((total_read_size < contlength) || cont_100) {
 		cont_100 = 0;
 		bytes_left = EXTRA_SIZE;
@@ -191,7 +222,7 @@ receive:
 			bytes_left = contlength - total_read_size;
 		if (bytes_left <= 0)
 			goto final;
-		size = recv(fd, zcu_buf_get_next(buf), bytes_left, 0);
+		size = recv(fd, u_buf_get_next(buf), bytes_left, 0);
 		if (size <= 0)
 			goto final;
 		buf->next += size;
@@ -199,7 +230,7 @@ receive:
 	}
 
 final:
-	zcu_buf_concat(buf, "\0");
+	u_buf_concat(buf, "\0");
 
 	return 0;
 }
@@ -631,27 +662,27 @@ static void nftlb_http_send_response(struct ev_io *io,
 
 static void nftlb_read_cb(struct ev_loop *loop, struct ev_io *io, int revents)
 {
-	struct zcu_buffer buf;
+	struct u_buffer buf;
 	struct nftlb_http_state state;
 	struct nftlb_client *cli;
 	ssize_t size;
 	char cli_address[INET6_ADDRSTRLEN + 6]; //max address length + port length
 
 	if (EV_ERROR & revents) {
-		zcu_log_print(LOG_ERR, "Server got invalid event from client read");
+		u_log_print(LOG_ERR, "Server got invalid event from client read");
 		return;
 	}
 	cli = container_of(io, struct nftlb_client, io);
 
-	zcu_buf_create(&buf);
-	size = recv(io->fd, zcu_buf_get_data(&buf), ZCU_DEF_BUFFER_SIZE - 1, 0);
+	u_buf_create(&buf);
+	size = recv(io->fd, u_buf_get_data(&buf), U_DEF_BUFFER_SIZE - 1, 0);
 	if (size < 0)
 		return;
 
 	buf.next = size;
 
 	if (size == 0) {
-		zcu_log_print(LOG_DEBUG, "connection closed by client %s\n",
+		u_log_print(LOG_DEBUG, "connection closed by client %s\n",
 					   nftlb_client_address(&cli->addr, cli_address));
 		goto end_no_state;
 	}
@@ -672,12 +703,12 @@ static void nftlb_read_cb(struct ev_loop *loop, struct ev_io *io, int revents)
 	nftlb_http_send_response(io, &state, strlen(state.body_response));
 	send(io->fd, state.body_response, strlen(state.body_response), 0);
 
-	zcu_log_print(LOG_DEBUG, "connection closed by server %s\n",
+	u_log_print(LOG_DEBUG, "connection closed by server %s\n",
 				   nftlb_client_address(&cli->addr, cli_address));
 end:
 	fin_http_state(&state);
 end_no_state:
-	zcu_buf_clean(&buf);
+	u_buf_clean(&buf);
 
 	ev_timer_stop(loop, &cli->timer);
 	nftlb_client_release(loop, cli);
@@ -692,7 +723,7 @@ static void nftlb_timer_cb(struct ev_loop *loop, ev_timer *timer, int events)
 
 	cli = container_of(timer, struct nftlb_client, timer);
 
-	zcu_log_print(LOG_ERR, "timeout for client %s\n",
+	u_log_print(LOG_ERR, "timeout for client %s\n",
 				   nftlb_client_address(&cli->addr, cli_address));
 
 	nftlb_client_release(loop, cli);
@@ -706,19 +737,19 @@ static void accept_cb(struct ev_loop *loop, struct ev_io *io, int revents)
 	int client_sd;
 
 	if (EV_ERROR & revents) {
-		zcu_log_print(LOG_ERR, "Server got an invalid event from client");
+		u_log_print(LOG_ERR, "Server got an invalid event from client");
 		return;
 	}
 
 	client_sd = accept(io->fd, (struct sockaddr *)&client_addr, &addrlen);
 	if (client_sd < 0) {
-		zcu_log_print(LOG_ERR, "Server accept error");
+		u_log_print(LOG_ERR, "Server accept error");
 		return;
 	}
 
 	cli = malloc(sizeof(struct nftlb_client));
 	if (!cli) {
-		zcu_log_print(LOG_ERR, "No memory available to allocate new client");
+		u_log_print(LOG_ERR, "No memory available to allocate new client");
 		return;
 	}
 	memcpy(&cli->addr, &client_addr, sizeof(cli->addr));
@@ -748,10 +779,10 @@ int server_init(void)
 	if (nftserver.host == NULL)
 		switch(nftserver.family) {
 		case AF_INET:
-			host = "0.0.0.0";
+			host = "127.0.0.1";
 			break;
 		case AF_INET6:
-			host = "::";
+			host = "::1";
 			break;
 		default:
 			host = INADDR_ANY;
@@ -770,26 +801,26 @@ int server_init(void)
 
 	s = getaddrinfo(host, port, &hints, &result);
 	if (s != 0) {
-		zcu_log_print(LOG_ERR, "getaddrinfo: %s\n", gai_strerror(s));
+		u_log_print(LOG_ERR, "getaddrinfo: %s\n", gai_strerror(s));
 		return -1;
 	}
 
 	server_sd = socket(result->ai_family, SOCK_STREAM, 0);
 	if (server_sd < 0) {
-		zcu_log_print(LOG_ERR, "Server socket error");
+		u_log_print(LOG_ERR, "Server socket error");
 		return -1;
 	}
 	setsockopt(server_sd, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(int));
 
 	if (bind(server_sd, result->ai_addr, result->ai_addrlen) != 0) {
-		zcu_log_print(LOG_ERR, "Server bind error");
+		u_log_print(LOG_ERR, "Server bind error");
 		freeaddrinfo(result);
 		return -1;
 	}
 	freeaddrinfo(result);
 
 	if (listen(server_sd, 2) < 0) {
-		zcu_log_print(LOG_ERR, "Server listen error");
+		u_log_print(LOG_ERR, "Server listen error");
 		return -1;
 	}
 	nftserver.sd = server_sd;
@@ -811,7 +842,7 @@ void server_set_host(const char *host)
 	nftserver.host = malloc(strlen(host)+1);
 
 	if (!nftserver.host) {
-		zcu_log_print(LOG_ERR, "No memory available to allocate the server host");
+		u_log_print(LOG_ERR, "No memory available to allocate the server host");
 		return;
 	}
 
@@ -822,7 +853,7 @@ void server_set_port(const char *port)
 {
 	nftserver.port = malloc(strlen(port)+1);
 	if (!nftserver.port) {
-		zcu_log_print(LOG_ERR, "No memory available to allocate the server port");
+		u_log_print(LOG_ERR, "No memory available to allocate the server port");
 		return;
 	}
 
@@ -836,7 +867,7 @@ void server_set_key(char *key)
 	if (!nftserver.key) {
 		nftserver.key = (char *)malloc(SRV_MAX_IDENT);
 		if (!nftserver.key) {
-			zcu_log_print(LOG_ERR, "No memory available to allocate the server key");
+			u_log_print(LOG_ERR, "No memory available to allocate the server key");
 			return;
 		}
 	}
